==> apache-camel-3.4.3-src.zip: apache-camel-3.4.3/components/camel-activemq/src/test/java/org/apache/camel/component/activemq/ActiveMQComponentUserNamePasswordTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.activemq;

import org.apache.camel.test.spring.junit5.CamelSpringTestSupport;
import org.junit.jupiter.api.Test;
import org.springframework.context.support.AbstractApplicationContext;
import org.springframework.context.support.ClassPathXmlApplicationContext;

import static org.junit.jupiter.api.Assertions.assertEquals;
import static org.junit.jupiter.api.Assertions.assertNotNull;

public class ActiveMQComponentUserNamePasswordTest extends CamelSpringTestSupport {

    @Override
    protected AbstractApplicationContext createApplicationContext() {
        return new ClassPathXmlApplicationContext("org/apache/camel/component/activemq/ActiveMQComponentUserNamePassword.xml");
    }

    @Test
    public void testActiveMQ() throws Exception {
        ActiveMQComponent comp = context.getComponent("activemq", ActiveMQComponent.class);
        assertNotNull(comp);

        ActiveMQConfiguration config = (ActiveMQConfiguration)comp.getConfiguration();
        assertNotNull(config);
        assertEquals("admin", config.getUserName());
        assertEquals("secret", config.getPassword());

        getMockEndpoint("mock:result").expectedBodiesReceived("Hello World");

        template.sendBody("activemq:queue:foo", "Hello World");

        assertMockEndpointsSatisfied();
    }
}

==> apache-camel-3.21.5-src.zip: apache-camel-3.21.5/components/camel-activemq/src/test/java/org/apache/camel/component/activemq/ActiveMQComponentUserNamePasswordTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.activemq;

import org.apache.camel.component.activemq.support.ActiveMQSpringTestSupport;
import org.apache.camel.component.mock.MockEndpoint;
import org.junit.jupiter.api.Test;

import static org.junit.jupiter.api.Assertions.assertEquals;
import static org.junit.jupiter.api.Assertions.assertNotNull;

public class ActiveMQComponentUserNamePasswordTest extends ActiveMQSpringTestSupport {

    @Test
    public void testActiveMQ() throws Exception {
        ActiveMQComponent comp = context.getComponent("activemq", ActiveMQComponent.class);
        assertNotNull(comp);

        ActiveMQConfiguration config = (ActiveMQConfiguration) comp.getConfiguration();
        assertNotNull(config);
        assertEquals("admin", config.getUsername());
        assertEquals("secret", config.getPassword());

        getMockEndpoint("mock:result").expectedBodiesReceived("Hello World");

        template.sendBody("activemq:queue:foo", "Hello World");

        MockEndpoint.assertIsSatisfied(context);
    }
}
